===========
licensename
===========


.. image:: https://img.shields.io/pypi/v/licensename.svg
        :target: https://pypi.python.org/pypi/licensename

.. image:: https://img.shields.io/travis/JulienPalard/licensename.svg
        :target: https://travis-ci.org/JulienPalard/licensename

.. image:: https://readthedocs.org/projects/licensename/badge/?version=latest
        :target: https://licensename.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Module and script to find a license name from a license text or file.

* Documentation: https://licensename.readthedocs.io.
